PortablePtyResult enum
Values
- Ok → const PortablePtyResult
-
const PortablePtyResult(0) - ErrOpen → const PortablePtyResult
-
const PortablePtyResult(1) - ErrSpawn → const PortablePtyResult
-
const PortablePtyResult(2) - ErrResize → const PortablePtyResult
-
const PortablePtyResult(3) - ErrRead → const PortablePtyResult
-
const PortablePtyResult(4) - ErrWrite → const PortablePtyResult
-
const PortablePtyResult(5) - ErrNull → const PortablePtyResult
-
const PortablePtyResult(6) - ErrWait → const PortablePtyResult
-
const PortablePtyResult(7) - ErrKill → const PortablePtyResult
-
const PortablePtyResult(8) - ErrMode → const PortablePtyResult
-
const PortablePtyResult(9) - ErrSize → const PortablePtyResult
-
const PortablePtyResult(10) - ErrWaitBlocking → const PortablePtyResult
-
const PortablePtyResult(11) - ErrProcessGroup → const PortablePtyResult
-
const PortablePtyResult(12)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → PortablePtyResult
Constants
-
values
→ const List<
PortablePtyResult> - A constant List of the values in this enum, in order of their declaration.